@@ -477,7 +477,7 @@ class Face():
 
         return left_pos, right_pos
 
-    def compose_eye_rot(self, eye_pos:list, face_orientation:np.ndarray, x2ang: int=180, y2ang:int=30):
+    def compose_eye_rot(self, eye_pos:list, face_orientation:np.ndarray, x2ang: int=180, y2ang:int=30)->np.ndarray:
         """Composes eye position with face rotation to produce eye orientation in world coordinates
 
         Args:
@@ -487,7 +487,7 @@ class Face():
             y2ang (int, optional): A coefficient to convert normalized position to angle in Y axis. Defaults to 30.
 
         Returns:
-            [type]: [description]
+            np.ndarray: [description]
         """
         fo = R.from_rotvec(face_orientation[:,0])
         ypr = R.from_euler('yxz',[-eye_pos[0]*x2ang,-eye_pos[1]*y2ang,0], degrees=True)
